# Celeratas

The Latin Programming Language

## Description

Built from python, Celeratas uses a custom ident-oriented syntax that features latin keywords. Although some of the text is written in latin, there is an English help menu with translations for all of the keywords.

## Getting Started

### Dependencies

-   Windows, Macos, Unix, or Linux
-   Python3

### Installing

-   Clone the Git Repository

### Executing program

-   Run shell.py with your python interpreter
-   Type auxilium to get started

```
python3 shell.py
auxilium
```

## Authors

Contributors names and contact info

Finn Mattis

## Version History

-   0.1
    -   Initial Release

## License

This project is licensed under the MIT License - see the LICENSE.md file for details
